<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Tuuma</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Jalka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Maili</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Millimetri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Senttimetri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Metri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Mikrotuuma</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Maili</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Jaardi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Ångström</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikroni</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Desimetri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekametri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hehtometri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigametri</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astronominen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Valovuosi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsek/Tähtiväli</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+288"/>
        <source>By Layer</source>
        <translation>Tason mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Lohkon mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Punainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Vihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Sininen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Sinivihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Purppura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Keltainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Oranssi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Tummanpunainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Tummanvihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Tummansininen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Tumma sinivihreä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Tumma purppura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Tummankeltainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Musta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Vaaleanharmaa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Valkoinen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Others...</source>
        <translation>Muut ...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>Nykyinen tason tunniste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Piirtoyksikkö</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Viivatyypin mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Kirjasimen mitta</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translation>Lohko</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation>Pikseliyksikkö</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Nollapiste</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Kulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Sarakkeet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Rivit</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Sarakeväli</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Riviväli</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Määritteet</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+91"/>
        <location filename="../src/core/RObject.cpp" line="+67"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>Lohkotunniste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Taso</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+102"/>
        <source>Linetype</source>
        <translation>Viivatyyppi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Viivatyypin mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Viivan paksuus</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Väri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Näytetty väri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Piirtojärjestys</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Rajaviiva</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Alapuoli</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Yläpuoli</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
        <source>Custom</source>
        <translation>Mukautettu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Kahva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Suojattu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Valittu</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Leveys</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Korkeus</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Yksinkertainen</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Tekstin sijainti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Teksti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Tavallinen teksti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Kirjasimen nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Tekstin korkeus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Tekstin kulma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X mittakaava</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Lihavoitu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Kursiivi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Riviväli</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Tasaus</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Vaakasuunta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Pystysuunta</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Kierto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation> </translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Näytä keskus</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Näytä kohde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Yleistä</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Piilotettu</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Jäädytetty</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Lukittu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Kutistettu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Piirturilla</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Tarttuva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Pois on jäädytetty</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Välilehden järjestys</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Minimirajat</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Maksimirajat</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Lisäosa</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Pienin määrä</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Suurin määrä</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Pyöreä (rekursiivinen) lohkojen vertailu havaittu:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Lohkon nimi:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
        <source>Requires selection</source>
        <translation>Vaatii valinnan</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Nimi</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Jäädytetty</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Piilotettu</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Lukittu</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Väri</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Viivan tyyppi</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Viivan paksuus</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translation type="vanished">Tason mukaan</translation>
    </message>
    <message>
        <source>By Block</source>
        <translation type="vanished">Lohkon mukaan</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translation type="vanished">Jatkuva</translation>
    </message>
    <message>
        <source>Dot</source>
        <translation type="vanished">Piste</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translation type="vanished">Piste (pieni)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translation type="vanished">Piste (suuri)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation type="vanished">Katkoviiva</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translation type="vanished">Katkoviiva (pieni)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translation type="vanished">Katkoviiva (suuri)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translation type="vanished">Katkoviiva - piste</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translation type="vanished">Katkoviiva - piste (pieni)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translation type="vanished">Katkoviiva - piste (suuri)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translation type="vanished">Jaa</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translation type="vanished">Jaa (pieni)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translation type="vanished">Jaa (suuri)</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Keskipiste</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translation type="vanished">Keskipiste (pieni)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translation type="vanished">Keskipiste (suuri)</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="vanished">Reuna</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translation type="vanished">Reuna (pieni)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translation type="vanished">Reuna (suuri)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrijärjestelmä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Kuvio</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Tason mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Lohkon mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Jatkuva</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Reuna</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Keskipiste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Viiva - piste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Katkoviiva</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Jaa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Piste</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Piilotettu</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Haamu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO ajatusviiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO ajatusviiva - välilyönti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO pitkä ajatusviiva - piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO pitkä ajatusviiva - tuplapiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO pitkäviiva - kolmoispiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO pitkäviiva - lyhytviiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO pitkäviiva - tupla lyhytviiva</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO viiva - piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO tuplaviiva - piste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO viiva - tuplapiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO tuplaviiva - tuplapiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO ajatusviiva - kolmoispiste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO pitkä ajatusviiva - kolmoispiste</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Kuuman veden jakelu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Kuuma vesi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Kaasuputki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Vanu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Siksak kuvio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Raidat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Aitalinja 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Aitalinja 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Viemäri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Salaojitus käänteinen</translation>
    </message>
    <message>
        <source>Drainage Reverse</source>
        <translation type="vanished">Viemäri käänteinen</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>Tason mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Lohkon mukaan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11 mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">Mukautettu</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Tyyppi</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">Kahva</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Suojattu</translation>
    </message>
</context>
</TS>
